from typing import List

import pytest
from pyramid.config import Configurator
from pyramid.interfaces import IRoutesMapper

RouteList = List[str]


@pytest.fixture()
def capability_routes() -> RouteList:
    return [
        "home",
        "view_capability",
        "view_active_capability_requests",
        "view_created_capability_requests",
        "create_capability",
        "edit_capability",
        "enable_capability",
        "disable_capability",
        "pause_capability",
        "unpause_capability",
        "view_capability_request",
        "create_capability_request",
        "create_and_submit_capability_request",
        "launch_capability_request_from_ingestion_details",
        "create_follow_on_capability_request",
        "edit_capability_request",
        "submit_capability_request",
        "cancel_capability_request",
        "delete_capability_request",
        "view_latest_version",
        "create_capability_version",
        "add_version_file",
    ]


def test_routes_exist(test_config: Configurator, capability_routes: RouteList):
    """
    Tests that the Pyramid config has the proper capability routes set up

    :param test_config: Mock pyramid config for testing purposes
    """
    test_config.include("capability.routes")
    mapper = test_config.registry.queryUtility(IRoutesMapper)
    route_names = [route.name for route in mapper.get_routes()]
    assert capability_routes == route_names
